@@ -1,16 +1,16 @@
 
 /*
  *  autogen.c
- *  $Id: autogen.c,v 4.15 2006/09/24 02:58:59 bkorb Exp $
+ *  $Id: autogen.c,v 4.20 2007/02/04 22:17:39 bkorb Exp $
  *
- *  Time-stamp:        "2006-09-23 19:56:03 bkorb"
- *  Last Committed:    $Date: 2006/09/24 02:58:59 $
+ *  Time-stamp:        "2007-02-04 08:28:43 bkorb"
+ *  Last Committed:    $Date: 2007/02/04 22:17:39 $
  *
  *  This is the main routine for autogen.
  */
 
 /*
- *  AutoGen copyright 1992-2006 Bruce Korb
+ *  AutoGen copyright 1992-2007 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -36,6 +36,8 @@ tSCC* apzStateName[] = { STATE_TABLE };
 #undef _State_
 
 static sigjmp_buf  abendJumpEnv;
+static int         abendJumpSignal = 0;
+
 typedef void (sighandler_proc_t)( int sig );
 static sighandler_proc_t ignoreSignal, abendSignal;
 
@@ -77,7 +79,7 @@ inner_main( int argc, char** argv )
     procState = PROC_STATE_LOAD_TPL;
 
     {
-        tTemplate* pTF = loadTemplate( pzTemplFileName );
+        tTemplate* pTF = loadTemplate(pzTemplFileName, NULL);
 
         procState = PROC_STATE_EMITTING;
         processTemplate( pTF );
@@ -96,11 +98,14 @@ main( int    argc,
       char** argv )
 {
     pfTrace = stderr;
-    {
-        int signo = sigsetjmp( abendJumpEnv, 0 );
-        if (signo != 0)
-            signalExit( signo );
-    }
+
+    /*
+     *  IF sigsetjmp returns with a signal number,
+     *  THEN you cannot capture the value portably.  So, the jumper has
+     *  stashed it for use now.
+     */
+    if (sigsetjmp( abendJumpEnv, 0 ) != 0)
+        signalExit( abendJumpSignal );
 
     signalSetup( ignoreSignal, abendSignal );
 
@@ -146,7 +151,8 @@ signalExit( int sig )
         tSCC zAt[]  = "processing template %s\n"
                       "            on line %d\n"
                       "       for function %s (%d)\n";
-        int line, fnCd;
+        int line;
+        teFuncType fnCd;
         tCC* pzFn;
         tCC* pzFl;
 
@@ -156,7 +162,8 @@ signalExit( int sig )
             fnCd = -1;
 
         } else {
-            int f = (pCurMacro->funcCode > FUNC_CT)
+            teFuncType f =
+                (pCurMacro->funcCode > FUNC_CT)
                     ? FTYP_SELECT : pCurMacro->funcCode;
             pzFn = apzFuncNames[ f ];
             line = pCurMacro->lineNo;
@@ -180,6 +187,7 @@ signalExit( int sig )
 static void
 abendSignal( int sig )
 {
+    abendJumpSignal = sig;
     siglongjmp( abendJumpEnv, sig );
 }
 
@@ -310,7 +318,7 @@ doneCheck( void )
     }
 
     do {
-        unsigned long pos = ftell( stderr );
+        long pos = ftell( stderr );
         char* pz;
 
         /*
@@ -320,8 +328,8 @@ doneCheck( void )
             break;
         pz = AGALOC( pos, "stderr redirected text" );
         rewind( stderr );
-        fread(  pz, 1, pos, stderr );
-        fwrite( pz, 1, pos, stdout );
+        fread(  pz, (size_t)1, (size_t)pos, stderr );
+        fwrite( pz, (size_t)1, (size_t)pos, stdout );
         AGFREE( pz );
     } while (0);
 
@@ -482,7 +490,7 @@ ao_malloc (size_t sz)
 {
     void * res = malloc(sz);
     if (res == NULL) {
-        fprintf( stderr, "malloc of %d bytes failed\n", sz );
+        fprintf(stderr, "malloc of %d bytes failed\n", (int)sz);
         exit( EXIT_FAILURE );
     }
     return res;
@@ -494,7 +502,7 @@ ao_realloc (void *p, size_t sz)
 {
     void * res = realloc(p, sz);
     if (res == NULL) {
-        fprintf( stderr, "realloc of %d bytes at 0x%p failed\n", sz, p );
+        fprintf(stderr, "realloc of %d bytes at 0x%p failed\n", (int)sz, p);
         exit( EXIT_FAILURE );
     }
     return res;
@@ -514,7 +522,7 @@ ao_strdup (char const * str)
 {
     char * res = strdup(str);
     if (res == NULL) {
-        fprintf( stderr, "strdup of %d byte string failed\n", strlen(str) );
+        fprintf(stderr, "strdup of %d byte string failed\n", (int)strlen(str));
         exit( EXIT_FAILURE );
     }
     return res;
