@@ -1,9 +1,9 @@
 
 /*
- *  $Id: defLex.c,v 4.16 2006/09/24 02:58:59 bkorb Exp $
+ *  $Id: defLex.c,v 4.19 2006/12/10 19:41:26 bkorb Exp $
  *
- *  Time-stamp:        "2006-09-23 19:54:51 bkorb"
- *  Last Committed:    $Date: 2006/09/24 02:58:59 $
+ *  Time-stamp:        "2006-12-10 11:03:53 bkorb"
+ *  Last Committed:    $Date: 2006/12/10 19:41:26 $
  *
  *  This module scans the template variable declarations and passes
  *  tokens back to the parser.
@@ -48,7 +48,7 @@ tSCC*  apzKeywords[] = { KEYWORD_TABLE };
 #undef _KW_
 
 #define _KW_(w) DP_EV_ ## w,
-int    aKeywordTkn[] = { KEYWORD_TABLE };
+te_dp_event aKeywordTkn[] = { KEYWORD_TABLE };
 #undef _KW_
 
 #define KEYWORD_CT  (sizeof( apzKeywords ) / sizeof( apzKeywords[0] ))
@@ -183,7 +183,7 @@ scanAgain:
         break;
 
     case '\\':
-        if (strncmp( pCurCtx->pzScan+1, "'(", 2) == 0) {
+        if (strncmp( pCurCtx->pzScan+1, "'(", (size_t)2) == 0) {
             alist_to_autogen_def();
             goto scanAgain;
 
@@ -281,23 +281,19 @@ NUL_error:
     return DP_EV_INVALID;
 
 lex_done:
-    {
-        tSCC zDone[] = "";
+    /*
+     *  First time through, return the DP_EV_END token.
+     *  Second time through, we really finish.
+     */
+    if (pCurCtx->pzScan == zNil) {
+        pCurCtx->pCtx = pDoneCtx;
+        pDoneCtx      = pCurCtx;
 
-        /*
-         *  First time through, return the DP_EV_END token.
-         *  Second time through, we really finish.
-         */
-        if (pCurCtx->pzScan == zDone) {
-            pCurCtx->pCtx = pDoneCtx;
-            pDoneCtx      = pCurCtx;
-
-            return DP_EV_INVALID;
-        }
-
-        pCurCtx->pzScan = (char*)zDone;
-        return DP_EV_END;
+        return DP_EV_INVALID;
     }
+
+    pCurCtx->pzScan = (char*)zNil;
+    return DP_EV_END;
 }
 
 
@@ -390,7 +386,7 @@ alist_to_autogen_def( void )
     char*  pzEnd   = (char*)skipScheme( pzText, pzText + strlen( pzText ));
 
     SCM    res;
-    u_int  res_len;
+    size_t res_len;
     tScanCtx*  pCtx;
 
     /*
@@ -550,7 +546,7 @@ assembleName( char* pzScan, te_dp_event* pRetVal )
                 /*
                  *  Return the keyword token code instead of DP_EV_NAME
                  */
-                *pRetVal = (te_dp_event)aKeywordTkn[ kw_ix ];
+                *pRetVal = aKeywordTkn[ kw_ix ];
                 break;
             }
         } while (++kw_ix < KEYWORD_CT);
@@ -572,7 +568,7 @@ assembleHereString( char* pzScan )
 {
     ag_bool  trimTabs = AG_FALSE;
     char     zMark[ MAX_HEREMARK_LEN ];
-    u_int    markLen = 0;
+    size_t   markLen = 0;
     char*    pzDest;
 
     /*
