@@ -1,13 +1,16 @@
 
-/*  -*- Mode: C -*-
- *
+/*
  *  expMake.c
- *  $Id: expMake.c,v 4.4 2005/12/04 22:26:21 bkorb Exp $
+ *  $Id: expMake.c,v 4.9 2006/12/10 19:41:26 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-12-10 11:04:31 bkorb"
+ *  Last Committed:    $Date: 2006/12/10 19:41:26 $
+ *
  *  This module implements Makefile construction functions.
  */
 
 /*
- *  AutoGen copyright 1992-2005 Bruce Korb
+ *  AutoGen copyright 1992-2006 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -117,7 +120,7 @@ ag_scm_makefile_script( SCM text )
     }
 
     if (*pzText == NUL)
-        return AG_SCM_STR02SCM( "" );
+        return AG_SCM_STR02SCM(zNil);
 
     {
         char*  pz  = strchr( pzText, '\n' );
@@ -266,7 +269,6 @@ ag_scm_makefile_script( SCM text )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/expMake.c */
