@@ -1,10 +1,10 @@
 
 /*
  *  expString.c
- *  $Id: expString.c,v 4.14 2006/09/24 02:58:59 bkorb Exp $
+ *  $Id: expString.c,v 4.16 2006/12/10 19:41:26 bkorb Exp $
  *
- *  Time-stamp:        "2006-09-23 19:52:39 bkorb"
- *  Last Committed:    $Date: 2006/09/24 02:58:59 $
+ *  Time-stamp:        "2006-12-10 11:05:08 bkorb"
+ *  Last Committed:    $Date: 2006/12/10 19:41:26 $
  *
  *  This module implements expression functions that
  *  manipulate string values.
@@ -374,10 +374,10 @@ do_substitution(
         if (pzNxt == NULL)
             break;
         if (pz != pzNxt) {
-            memcpy( pzScan, pz, (unsigned)(pzNxt - pz) );
+            memcpy( pzScan, pz, (size_t)(pzNxt - pz) );
             pzScan += (pzNxt - pz);
         }
-        memcpy( pzScan, pzRepl, (unsigned)replL );
+        memcpy( pzScan, pzRepl, (size_t)replL );
         pzScan += replL;
         pz = pzNxt + matchL;
     }
@@ -543,7 +543,7 @@ ag_scm_join( SCM sep, SCM list )
 
     sv_l_len = l_len = scm_ilength( list );
     if (l_len == 0)
-        return AG_SCM_STR02SCM( "" );
+        return AG_SCM_STR02SCM(zNil);
 
     pzSep   = AG_SCM_CHARS( sep );
     sep_len = AG_SCM_STRLEN( sep );
