@@ -1,12 +1,15 @@
 
 /*
- *  $Id: loadPseudo.c,v 4.5 2006/03/25 19:24:49 bkorb Exp $
+ *  $Id: loadPseudo.c,v 4.11 2007/02/04 17:44:12 bkorb Exp $
+ *
+ *  Time-stamp:        "2007-01-29 16:35:59 bkorb"
+ *  Last Committed:    $Date: 2007/02/04 17:44:12 $
  *
  *  This module processes the "pseudo" macro
  */
 
 /*
- *  AutoGen copyright 1992-2006 Bruce Korb
+ *  AutoGen copyright 1992-2007 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -46,7 +49,7 @@ static te_pm_event
 findTokenType( tCC**  ppzData, te_pm_state fsm_state );
 
 static tCC*
-copyMarker( tCC* pzData, char* pzMark, int* pCt );
+copyMarker( tCC* pzData, char* pzMark, size_t * pCt );
 /* = = = END-STATIC-FORWARD = = = */
 
 
@@ -98,17 +101,32 @@ doSuffixSpec( tCC* pzData, tCC* pzFileName, int lineNo )
      *  also allow a format specification to follow the suffix,
      *  separated by an '=' character.
      */
-    tSCC zSuffixSpecChars[] = "abcdefghijklmnopqrstuvwxyz"
-          "ABCDEFGHIJKLMNOPQRSTUVWXYZ" "0123456789" "-_./" "=%";
+    tSCC zSuffixSpecChars[] = "=%" "abcdefghijklmnopqrstuvwxyz"
+          "ABCDEFGHIJKLMNOPQRSTUVWXYZ" "0123456789" "-_./";
 
     tOutSpec*  pOS;
-    char*      pz;
+    tCC*       pzSfxFmt;
+    tCC*       pzResult;
     static tOutSpec**  ppOSList = &pOutSpecList;
 
     /*
      *  Skip over the suffix construct
      */
-    size_t spn = strspn( pzData, zSuffixSpecChars );
+    size_t spn = strspn( pzData, zSuffixSpecChars+2 );
+
+    if (pzData[spn] != '=') {
+        pzSfxFmt = NULL;
+    } else {
+        pzSfxFmt = pzData + spn;
+        if (pzSfxFmt[1] == '(') {
+            tCC *pe  = pzSfxFmt + 1 + strlen( pzSfxFmt + 1 );
+            tCC *ptr = skipScheme( pzSfxFmt+1, pe );
+            spn = ptr - pzData;
+        } else {
+            spn += strspn( pzSfxFmt, zSuffixSpecChars );
+        }
+    }
+    pzResult = pzData + spn;
 
     /*
      *  If pzFileName is NULL, then we are called by --select-suffix.
@@ -118,7 +136,7 @@ doSuffixSpec( tCC* pzData, tCC* pzFileName, int lineNo )
     if (  (pzFileName != NULL)
        && (  (procState != PROC_STATE_LOAD_TPL)
           || HAVE_OPT( SELECT_SUFFIX )))
-        return pzData + spn;
+        return pzResult;
 
     /*
      *  Allocate the suffix structure
@@ -139,17 +157,37 @@ doSuffixSpec( tCC* pzData, tCC* pzFileName, int lineNo )
      *  THEN split it off from the suffix and set the formatting ptr.
      *  ELSE supply a default.
      */
-    strncpy( pOS->zSuffix, pzData, spn );
+    memcpy( pOS->zSuffix, pzData, spn );
     pOS->zSuffix[ spn ] = NUL;
 
-    pz = strchr( pOS->zSuffix, '=' );
+    if (pzSfxFmt != NULL) {
+        spn = pzSfxFmt - pzData;
+        pOS->zSuffix[spn] = NUL;
+        pzSfxFmt = pOS->zSuffix + spn + 1;
 
-    if (pz != NULL) {
-        tSCC zFileFmt3[] = "%s";
-        *pz++ = NUL;
-        if (*pz == NUL)
-             pOS->pzFileFmt = zFileFmt3;
-        else pOS->pzFileFmt = pz;
+        switch (*pzSfxFmt) {
+        case NUL:
+        {
+            tSCC zFileFmt3[] = "%s";
+            pOS->pzFileFmt = zFileFmt3;
+            break;
+        }
+
+        case '(':
+        {
+            SCM str =
+                ag_scm_c_eval_string_from_file_line(
+                    pzSfxFmt, pzFileName, lineNo );
+            tCC *pzStr;
+            AGDUPSTR( pzStr, resolveSCM( str ), "Scheme suffix format");
+            pOS->pzFileFmt = pzStr;
+            break;
+        }
+
+        default:
+            pOS->pzFileFmt = pzSfxFmt;
+            break;
+        }
 
     } else {
         tSCC zFileFmt1[] = "%s.%s";
@@ -164,7 +202,7 @@ doSuffixSpec( tCC* pzData, tCC* pzFileName, int lineNo )
         else pOS->pzFileFmt = zFileFmt2;
     }
 
-    return pzData + spn;
+    return pzResult;
 }
 
 
@@ -226,7 +264,7 @@ findTokenType( tCC**  ppzData, te_pm_state fsm_state )
      *  THEN it must be "autogen5" or "template" or a suffix specification
      */
     if (isalnum( *pzData )) {
-        if (strneqvcmp( pzData, zAgName, sizeof(zAgName)-1 ) == 0) {
+        if (strneqvcmp( pzData, zAgName, (int)sizeof(zAgName)-1 ) == 0) {
             if (isspace( pzData[ sizeof(zAgName)-1 ] )) {
                 *ppzData = pzData + sizeof(zAgName);
                 return PM_EV_AUTOGEN;
@@ -235,7 +273,7 @@ findTokenType( tCC**  ppzData, te_pm_state fsm_state )
             return PM_EV_SUFFIX;
         }
 
-        if (strneqvcmp( pzData, zTpName, sizeof(zTpName)-1 ) == 0) {
+        if (strneqvcmp( pzData, zTpName, (int)sizeof(zTpName)-1 ) == 0) {
             if (isspace( pzData[ sizeof(zTpName)-1 ] )) {
                 *ppzData = pzData + sizeof(zTpName)-1;
                 return PM_EV_TEMPLATE;
@@ -271,7 +309,7 @@ findTokenType( tCC**  ppzData, te_pm_state fsm_state )
      *  IF the next sequence is "-*-"
      *  THEN we found an edit mode marker
      */
-    if (strncmp( pzData, "-*-", 3 ) == 0)
+    if (strncmp(pzData, "-*-", (size_t)3) == 0)
         return PM_EV_ED_MODE;
 
     /*
@@ -298,7 +336,7 @@ findTokenType( tCC**  ppzData, te_pm_state fsm_state )
  *  as we find punctuation characters.
  */
 static tCC*
-copyMarker( tCC* pzData, char* pzMark, int* pCt )
+copyMarker( tCC* pzData, char* pzMark, size_t * pCt )
 {
     int ct = 0;
 
@@ -450,7 +488,6 @@ loadPseudoMacro( tCC* pzData, tCC* pzFileName )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/loadPseudo.c */
